==> gcc-4.3.4.tar.bz2: gcc-4.3.4/libjava/classpath/gnu/xml/transform/TemplatesImpl.java <==
/* TemplatesImpl.java -- 
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.transform;

import java.util.Properties;
import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;

/**
 * GNU precompiled stylesheet implementation.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
class TemplatesImpl
  implements Templates
{

  final TransformerFactoryImpl factory;
  final Stylesheet stylesheet;
  final Properties outputProperties;

  TemplatesImpl(TransformerFactoryImpl factory, Stylesheet stylesheet)
  {
    this.factory = factory;
    this.stylesheet = stylesheet;
    outputProperties = new TransformerOutputProperties(stylesheet);
  }

  public Transformer newTransformer()
    throws TransformerConfigurationException
  {
    Stylesheet stylesheet = (Stylesheet) this.stylesheet.clone();
    TransformerImpl transformer =
      new TransformerImpl(factory, stylesheet, outputProperties);
    stylesheet.transformer = transformer;
    return transformer;
  }

  public Properties getOutputProperties()
  {
    return (Properties) outputProperties.clone();
  }
  
}

==> gcc-5.2.0.tar.bz2: gcc-5.2.0/libjava/classpath/gnu/xml/transform/TemplatesImpl.java <==
/* TemplatesImpl.java --
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.xml.transform;

import gnu.java.lang.CPStringBuilder;

import java.util.Properties;
import javax.xml.transform.Templates;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;

/**
 * GNU precompiled stylesheet implementation.
 *
 * @author <a href='mailto:dog@gnu.org'>Chris Burdess</a>
 */
class TemplatesImpl
  implements Templates
{

  final TransformerFactoryImpl factory;
  final Stylesheet stylesheet;
  final Properties outputProperties;

  TemplatesImpl(TransformerFactoryImpl factory, Stylesheet stylesheet)
  {
    this.factory = factory;
    this.stylesheet = stylesheet;
    outputProperties = new TransformerOutputProperties(stylesheet);
  }

  public Transformer newTransformer()
    throws TransformerConfigurationException
  {
    Stylesheet stylesheet = (Stylesheet) this.stylesheet.clone();
    TransformerImpl transformer =
      new TransformerImpl(factory, stylesheet, outputProperties);
    stylesheet.transformer = transformer;
    return transformer;
  }

  public Properties getOutputProperties()
  {
    return (Properties) outputProperties.clone();
  }

  public String toString()
  {
    CPStringBuilder b = new CPStringBuilder(getClass().getName());
    b.append("[factory=");
    b.append(factory);
    b.append(",stylesheet=");
    b.append(stylesheet);
    b.append(",outputProperties=");
    b.append(outputProperties);
    b.append("]");
    return b.toString();
  }

}
